==> open-cluster-management-apps-model-5.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/SecretKeySelectorBuilder.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SecretKeySelectorBuilder extends io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorFluentImpl<io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelector,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorBuilder>{
  public SecretKeySelectorBuilder() {
    this(false);
  }
  public SecretKeySelectorBuilder(java.lang.Boolean validationEnabled) {
    this(new SecretKeySelector(), validationEnabled);
  }
  public SecretKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SecretKeySelector(), validationEnabled);
  }
  public SecretKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorFluent<?> fluent,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelector instance) {
    this(fluent, instance, false);
  }
  public SecretKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorFluent<?> fluent,io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withFieldPath(instance.getFieldPath()); 
    fluent.withKey(instance.getKey()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withResourceVersion(instance.getResourceVersion()); 
    fluent.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  public SecretKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelector instance) {
    this(instance,false);
  }
  public SecretKeySelectorBuilder(io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelector instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldPath(instance.getFieldPath()); 
    this.withKey(instance.getKey()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withResourceVersion(instance.getResourceVersion()); 
    this.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelectorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1.SecretKeySelector build() {
    SecretKeySelector buildable = new SecretKeySelector(fluent.getApiVersion(),fluent.getFieldPath(),fluent.getKey(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getResourceVersion(),fluent.getUid());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretKeySelectorBuilder that = (SecretKeySelectorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-apps-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/SecretKeySelectorBuilder.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SecretKeySelectorBuilder extends SecretKeySelectorFluentImpl<SecretKeySelectorBuilder> implements VisitableBuilder<SecretKeySelector,SecretKeySelectorBuilder>{
  public SecretKeySelectorBuilder() {
    this(false);
  }
  public SecretKeySelectorBuilder(Boolean validationEnabled) {
    this(new SecretKeySelector(), validationEnabled);
  }
  public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent) {
    this(fluent, false);
  }
  public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SecretKeySelector(), validationEnabled);
  }
  public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,SecretKeySelector instance) {
    this(fluent, instance, false);
  }
  public SecretKeySelectorBuilder(SecretKeySelectorFluent<?> fluent,SecretKeySelector instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withFieldPath(instance.getFieldPath()); 
    fluent.withKey(instance.getKey()); 
    fluent.withKind(instance.getKind()); 
    fluent.withName(instance.getName()); 
    fluent.withNamespace(instance.getNamespace()); 
    fluent.withResourceVersion(instance.getResourceVersion()); 
    fluent.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  public SecretKeySelectorBuilder(SecretKeySelector instance) {
    this(instance,false);
  }
  public SecretKeySelectorBuilder(SecretKeySelector instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withFieldPath(instance.getFieldPath()); 
    this.withKey(instance.getKey()); 
    this.withKind(instance.getKind()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withResourceVersion(instance.getResourceVersion()); 
    this.withUid(instance.getUid()); 
    this.validationEnabled = validationEnabled; 
  }
  SecretKeySelectorFluent<?> fluent;
  Boolean validationEnabled;
  public SecretKeySelector build() {
    SecretKeySelector buildable = new SecretKeySelector(fluent.getApiVersion(),fluent.getFieldPath(),fluent.getKey(),fluent.getKind(),fluent.getName(),fluent.getNamespace(),fluent.getResourceVersion(),fluent.getUid());
    return buildable;
  }
  
}
